==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
var LastMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LastMonthExpressionDescriptionMetadata, _super);
    function LastMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastMonthExpressionDescriptionMetadata.b = function (a) {
        if (LastMonthExpressionDescriptionMetadata.a == null) {
            LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
        }
        if (a.j(LastMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(LastMonthExpressionDescriptionMetadata.a);
    };
    LastMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastMonthExpressionDescriptionMetadata.d = function (a) {
        LastMonthExpressionDescriptionMetadata.b(a);
        a.aa("LastMonthExpression", function () { return new LastMonthExpressionDescription(); });
        a.z("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
    };
    LastMonthExpressionDescriptionMetadata.$t = markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
}(Base));
export { LastMonthExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/LastMonthExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { LastMonthExpressionDescription } from "./LastMonthExpressionDescription";
/**
 * @hidden
 */
var LastMonthExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(LastMonthExpressionDescriptionMetadata, _super);
    function LastMonthExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    LastMonthExpressionDescriptionMetadata.b = function (a) {
        if (LastMonthExpressionDescriptionMetadata.a == null) {
            LastMonthExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            LastMonthExpressionDescriptionMetadata.c(LastMonthExpressionDescriptionMetadata.a);
        }
        if (a.k(LastMonthExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(LastMonthExpressionDescriptionMetadata.a);
    };
    LastMonthExpressionDescriptionMetadata.c = function (a) {
        WrapperExpressionDescriptionMetadata.c(a);
    };
    LastMonthExpressionDescriptionMetadata.d = function (a) {
        LastMonthExpressionDescriptionMetadata.b(a);
        a.ac("LastMonthExpression", function () { return new LastMonthExpressionDescription(); });
        a.ab("LastMonthExpression", LastMonthExpressionDescriptionMetadata.a);
    };
    LastMonthExpressionDescriptionMetadata.$t = markType(LastMonthExpressionDescriptionMetadata, 'LastMonthExpressionDescriptionMetadata');
    LastMonthExpressionDescriptionMetadata.a = null;
    return LastMonthExpressionDescriptionMetadata;
}(Base));
export { LastMonthExpressionDescriptionMetadata };
